# $Id: proftpd.spec

%{?dist: %{expand: %%define %dist 1}}

%{?rh7:%define _without_acl 1}
%{?el2:%define _without_acl 1}
%{?el2:%define _without_postgresql 1}

Summary: Flexible, stable and highly-configurable FTP server
Name: proftpd
Version: 1.3.4d
Release: 1BX1
License: GPL
Group: System Environment/Daemons
URL: http://www.proftpd.org/
Packager: Michael Stauber <mstauber@solarspeed.net>
Vendor: Project BlueOnyx
Source0: ftp://ftp.proftpd.org/distrib/source/proftpd-%{version}.tar.gz
Source1: proftpd.conf
Source2: proftpd.init
Source3: proftpd-xinetd
Source4: proftpd-bluequartz.logrotate
Source5: welcome.msg
Source6: proftpd.pam.shadow
Source7: proftpds-xinetd
Source8: fixproftpd_conf_proftpd.pl

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: pam-devel, ncurses-devel, pkgconfig
BuildRequires: openssl-devel, krb5-devel
BuildRequires: openldap-devel, mysql-devel, zlib-devel
%{!?_without_acl:BuildRequires: libacl-devel}
%{!?_without_postgresql:BuildRequires: postgresql-devel}
Requires: pam >= 0.59
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/service, /sbin/chkconfig
Requires(postun): /sbin/service
Provides: ftpserver

%description
ProFTPD is an enhanced FTP server with a focus toward simplicity, security,
and ease of configuration. It features a very Apache-like configuration
syntax, and a highly customizable server infrastructure, including support for
multiple 'virtual' FTP servers, anonymous FTP, and permission-based directory
visibility.

This package defaults to the xinetd behaviour of ProFTPD, but all the
needed scripts to have it run as standalone are included as well.

%package devel
Summary: Header files, libraries and development documentation for %{name}.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files, static libraries and development
documentation for %{name}. If you like to develop programs using %{name},
you will need to install %{name}-devel.

%package ldap
Summary: Module to add LDAP support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description ldap
Module to add LDAP support to the ProFTPD FTP server.

%package mysql
Summary: Module to add MySQL support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description mysql
Module to add MySQL support to the ProFTPD FTP server.

%package postgresql
Summary: Module to add PostgreSQL support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description postgresql
Module to add PostgreSQL support to the ProFTPD FTP server.

%prep
%setup

# Disable stripping in order to get useful debuginfo packages
%{__perl} -pi -e 's|"-s"|""|g' configure

%build
if pkg-config openssl; then
    export CFLAGS="%{optflags} $(pkg-config --cflags openssl)"
    export LDFLAGS="$LDFLAGS $(pkg-config --libs-only-L openssl)"
fi
%configure \
    --libexecdir="%{_libexecdir}/proftpd" \
    --localstatedir="%{_var}/run" \
    --enable-ctrls \
    --enable-dso \
%{!?_without_acl:--enable-facl} \
    --enable-ipv6 \
    --enable-openssl \
    --with-includes="%{_includedir}/mysql" \
    --with-libraries="%{_libdir}/mysql" \
    --with-modules="mod_readme:mod_auth_pam:mod_tls:mod_ban" \
    --with-shared="mod_ldap:mod_sql:mod_sql_mysql:%{!?_without_postgresql:mod_sql_postgres:}mod_quotatab:mod_quotatab_file:mod_quotatab_ldap:mod_quotatab_sql"
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR="%{buildroot}" \
    rundir="%{_var}/run/proftpd" \
    INSTALL_USER=`id -un` \
    INSTALL_GROUP=`id -gn`
%{__install} -D -p -m 0640 %{SOURCE1} %{buildroot}%{_sysconfdir}/proftpd.conf
%{__install} -D -p -m 0640 %{SOURCE1} %{buildroot}%{_sysconfdir}/proftpd.conf.dist
%{__install} -D -p -m 0755 %{SOURCE2} \
    %{buildroot}%{_sysconfdir}/rc.d/init.d/proftpd
%{__install} -D -p -m 0640 %{SOURCE3} \
    %{buildroot}%{_sysconfdir}/xinetd.d/proftpd
%{__install} -D -p -m 0640 %{SOURCE7} \
    %{buildroot}%{_sysconfdir}/xinetd.d/proftpds
%{__install} -D -p -m 0644 %{SOURCE4} \
    %{buildroot}%{_sysconfdir}/logrotate.d/proftpd
%{__install} -D -p -m 0644 %{SOURCE5} %{buildroot}/var/ftp/welcome.msg
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/pam.d/proftpd
%{__install} -D -p -m 0755 %{SOURCE8} %{buildroot}/usr/sausalito/sbin/fixproftpd_conf_proftpd.pl

%{__mkdir_p} %{buildroot}/var/ftp/uploads
%{__mkdir_p} %{buildroot}/var/ftp/pub
%{__mkdir_p} %{buildroot}/var/log/proftpd
touch %{buildroot}%{_sysconfdir}/ftpusers

%clean
%{__rm} -rf %{buildroot}

%post
if [ $1 -eq 1 ]; then
#    /sbin/chkconfig --add proftpd
    IFS=":"; cat /etc/passwd | \
    while { read username nu nu gid nu nu nu nu; }; do \
        if [ $gid -lt 100 -a "$username" != "ftp" ]; then
            echo $username >> %{_sysconfdir}/ftpusers
        fi
    done
fi

if [ -f /etc/pam.d/proftpd.rpmnew ]; then
	/bin/mv /etc/pam.d/proftpd.rpmnew /etc/pam.d/proftpd
fi

if [ "$(uname -m)" = "x86_64" ]; then
	/usr/bin/perl -pi -e 's/\/lib\//\/lib64\//' /etc/pam.d/proftpd
fi

# Replace the onboard proftpd.conf with proftpd.conf.dist:
/bin/cat /etc/proftpd.conf.dist > /etc/proftpd.conf

# Re-add the now missing VirtualHost containers - but only do so
# if a previous proftpd was already installed. Because then it was
# an upgrade, not a first install:
if [ -f /etc/proftpd.conf.pre-1.3.4d ]; then
    /usr/sausalito/sbin/fixproftpd_conf_proftpd.pl >> /etc/proftpd.conf
fi

# Rotate the old proftpd.conf from prior to the update back in:
#if [ -f /etc/proftpd.conf.pre-1.3.4d ]; then
#    /bin/cp /etc/proftpd.conf.pre-1.3.4d /etc/proftpd.conf
#fi

# Restart of xinetd:
/etc/init.d/xinetd restart &>/dev/null || :

%pre
# Pre-install cleanup:
if [ -f /etc/pam.d/proftpd.rpmnew ]; then
    /bin/rm -f /etc/pam.d/proftpd.rpmnew
fi

if [ -f /etc/proftpd.conf.rpmnew ]; then
    /bin/rm -f /etc/proftpd.conf.rpmnew
fi

# Make backup of pre-existing /etc/proftpd.conf:
if [ -f /etc/proftpd.conf ]; then
    /bin/cp /etc/proftpd.conf /etc/proftpd.conf.pre-1.3.4d
fi

%preun
if [ $1 -eq 0 ]; then
    /sbin/service proftpd stop &>/dev/null || :
    /etc/init.d/xinetd stop &>/dev/null || :
    /sbin/chkconfig --del proftpd
    /sbin/service xinetd reload &>/dev/null || :
    if [ -d %{_var}/run/proftpd ]; then
        rm -rf %{_var}/run/proftpd/*
    fi
fi

%postun
if [ $1 -ge 1 ]; then
    /etc/init.d/xinetd restart &>/dev/null || :
fi

%files
%defattr(-, root, root, 0755)
%doc COPYING CREDITS ChangeLog NEWS README* doc/* sample-configurations/
%dir %{_localstatedir}/run/
%config(noreplace) %{_sysconfdir}/proftpd.conf
%config %{_sysconfdir}/proftpd.conf.dist
%config(noreplace) %{_sysconfdir}/xinetd.d/proftpd
%config(noreplace) %{_sysconfdir}/xinetd.d/proftpds
%config %{_sysconfdir}/ftpusers
%config(noreplace) %{_sysconfdir}/pam.d/proftpd
%config(noreplace) %{_sysconfdir}/logrotate.d/proftpd
%{_sysconfdir}/rc.d/init.d/proftpd
%{_mandir}/man?/*
%{_bindir}/*
%dir %{_libexecdir}/proftpd/
%{_libexecdir}/proftpd/mod_quotatab.so
%{_libexecdir}/proftpd/mod_quotatab_file.so
%{_libexecdir}/proftpd/mod_sql.so
%{_sbindir}/*
%dir /var/ftp/
%dir /var/ftp/pub/
/usr/sausalito/sbin/fixproftpd_conf_proftpd.pl
%config(noreplace) /var/ftp/welcome.msg
#%config(noreplace) /usr/lib/pkgconfig/proftpd.pc

%defattr(0331, ftp, ftp, 0331)
%dir /var/ftp/uploads/

%defattr(0750, root, root, 0750)
%dir /var/log/proftpd/
%exclude %{_libexecdir}/proftpd/*.a
%exclude %{_libexecdir}/proftpd/*.la

%files devel
%defattr(-, root, root, 0755)
%{_includedir}/proftpd/

%files ldap
%defattr(-, root, root, 0755)
%dir %{_libexecdir}/proftpd/
%{_libexecdir}/proftpd/mod_ldap.so
%{_libexecdir}/proftpd/mod_quotatab_ldap.so

%files mysql
%defattr(-, root, root, 0755)
%dir %{_libexecdir}/proftpd/
%{_libexecdir}/proftpd/mod_sql_mysql.so
%{_libexecdir}/proftpd/mod_quotatab_sql.so

%if %{!?_without_postgresql:1}0
%files postgresql
%defattr(-, root, root, 0755)
%dir %{_libexecdir}/proftpd/
%{_libexecdir}/proftpd/mod_sql_postgres.so
%{_libexecdir}/proftpd/mod_quotatab_sql.so
%endif

%changelog
* Sat Jan 25 2014 Michael Stauber <mstauber@solarspeed.net> 1.3.4d-1BX1
- Rebuilt with 1.3.4d
- Modified proftpd.conf for better sftp/ftps support.
